/*************************************************************************************\


 #     #   #####   #     #   #####    #####   ######      #  #######  #####   ######
 #     #  #     #  ##    #  #     #  #     #  #     #    #      #    #     #  #     #
 #  #  #  #     #  # #   #  #              #  #     #   #       #          #  #     #
 #  #  #  #######  #  #  #  # #####   #####   #     #  #   #    #     #####   #     #
 #  #  #  #     #  #   # #  #     #        #  #     #  #######  #          #  #     #
 #  #  #  #     #  #    ##  #     #  #     #  #     #      #    #    #     #  #     #      
  ## ##   #     #  #     #   #####    #####   ######       #    #     #####   ######


                                  Preprocessor of
                 3D Wang Tiles with Ellipsoidal Inclusions for T3D
                           Copyright: Daniel Rypl 2018

\*************************************************************************************/

/* IMPORTANT: this file is included in wang3d4t3d.c and uses static global variables defined there !!! */

#define process_aa_side_geometry                   process_z_side_geometry
#define check_inclusion_outside_tile_aa_side       check_inclusion_outside_tile_z_side
#define get_aa_side_patch_id_inner                 get_z_side_patch_id_inner
#define get_aa_side_patch_id_outer                 get_z_side_patch_id_outer
#define aa_intersection                            z_intersection
#define aa_touching                                z_touching
#define output_bb_edge_vertex                      output_x_edge_vertex
#define output_cc_edge_vertex                      output_y_edge_vertex
#define output_bb_edge_curve                       output_x_edge_curve
#define output_cc_edge_curve                       output_y_edge_curve
#define halving_bb                                 halving_x
#define halving_cc                                 halving_y
#define aa_face_is                                 z_face_is
#define bb_face_is                                 x_face_is
#define cc_face_is                                 y_face_is
#define bb_edge_is                                 x_edge_is
#define cc_edge_is                                 y_edge_is
#define aa_ind                                     z_ind
#define bb_ind                                     x_ind
#define cc_ind                                     y_ind
#define ind_aa                                     ind_z
#define ind_bb                                     ind_x
#define ind_cc                                     ind_y
#define bbbb_ind                                   xx_ind
#define cccc_ind                                   yy_ind
#define shift_aa                                   shift_z
#define shift_bb                                   shift_x
#define shift_cc                                   shift_y
#define aa_patch_id                                z_patch_id
#define bb_count                                   x_count
#define cc_count                                   y_count
#define bb_curve_id                                x_curve_id
#define cc_curve_id                                y_curve_id
#define sign_bb                                    sign_x
#define sign_cc                                    sign_y
#define aa_side_vertex_array                       z_side_vertex_array
#define aa_side_vertices                           z_side_vertices
#define bb_edge_vertex_id_array                    x_edge_vertex_id_array
#define cc_edge_vertex_id_array                    y_edge_vertex_id_array
#define bb_edge_vertex_data_array                  x_edge_vertex_data_array
#define cc_edge_vertex_data_array                  y_edge_vertex_data_array
#define bb_edge_vertices                           x_edge_vertices
#define cc_edge_vertices                           y_edge_vertices
#define bb_edge_curve_1_array                      x_edge_curve_1_array
#define cc_edge_curve_1_array                      y_edge_curve_1_array
#define bb_edge_curves_1                           x_edge_curves_1
#define cc_edge_curves_1                           y_edge_curves_1
#define bb_edge_curves_2                           x_edge_curves_2
#define cc_edge_curves_2                           y_edge_curves_2
#define aa_side_patch_array                        z_side_patch_array
#define aa_side_patches                            z_side_patches 
#ifndef HALF_MAX_TILES
#define aa_side_patches_total                      z_side_patches_total
#endif
#define aa_side_curve_array_inner                  z_side_curve_array_inner
#define aa_side_curve_array_outer                  z_side_curve_array_outer
#define aa_side_curves_inner                       z_side_curves_inner
#define aa_side_curves_outer                       z_side_curves_outer
#define dir_aa                                     dir_z

#define aa                                         z
#define bb                                         x
#define cc                                         y

#define AA                                         Z
#define BB                                         X
#define CC                                         Y

#define AABB                                       ZX
#define AACC                                       ZY
#define BBAA                                       XZ
#define CCAA                                       YZ

#ifdef DEBUG_PRINT
#define string_aa                                  "z"
#define string_bb                                  "x"
#define string_cc                                  "y"
#endif

#include "geom3d_xyz.c"

/* IMPORTANT: note that this file is included in wang3d4t3d.c
	 it is therefore necessary to undef all above directives to prevent their application to code following the inclusion */

#undef process_aa_side_geometry
#undef check_inclusion_outside_tile_aa_side
#undef get_aa_side_patch_id_inner
#undef get_aa_side_patch_id_outer
#undef aa_intersection
#undef aa_touching
#undef output_bb_edge_vertex
#undef output_cc_edge_vertex
#undef output_bb_edge_curve
#undef output_cc_edge_curve
#undef halving_bb
#undef halving_cc
#undef aa_face_is
#undef bb_face_is
#undef cc_face_is
#undef bb_edge_is
#undef cc_edge_is
#undef aa_ind
#undef bb_ind
#undef cc_ind
#undef ind_aa
#undef ind_bb
#undef ind_cc
#undef bbbb_ind
#undef cccc_ind
#undef shift_aa
#undef shift_bb
#undef shift_cc
#undef bb_count
#undef cc_count
#undef aa_patch_id
#undef bb_curve_id
#undef cc_curve_id
#undef sign_bb
#undef sign_cc
#undef aa_side_vertex_array
#undef aa_side_vertices
#undef bb_edge_vertex_id_array
#undef cc_edge_vertex_id_array
#undef bb_edge_vertex_data_array
#undef cc_edge_vertex_data_array
#undef bb_edge_vertices
#undef cc_edge_vertices
#undef bb_edge_curve_1_array
#undef cc_edge_curve_1_array
#undef bb_edge_curves_1
#undef cc_edge_curves_1
#undef bb_edge_curves_2
#undef cc_edge_curves_2
#undef aa_side_patch_array
#undef aa_side_patches
#ifndef HALF_MAX_TILES
#undef aa_side_patches_total
#endif
#undef aa_side_curve_array_inner
#undef aa_side_curve_array_outer
#undef aa_side_curves_inner
#undef aa_side_curves_outer
#undef dir_aa

#undef aa
#undef bb
#undef cc

#undef AA
#undef BB
#undef CC

#undef AABB
#undef AACC
#undef BBAA
#undef CCAA

#ifdef DEBUG_PRINT
#undef string_aa
#undef string_bb
#undef string_cc
#endif

